==> haskell-pcre-light-0.4.0.4-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-light.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-light
version: 0.4.0.4
id: pcre-light-0.4.0.4-AoPPcWPoSh8CV8nUAbwYS0
key: pcre-light-0.4.0.4-AoPPcWPoSh8CV8nUAbwYS0
license: BSD3
copyright: (c) 2007-2010. Don Stewart <dons@galois.com>
maintainer: Daniel Díaz <dhelta.diaz@gmail.com>
homepage: https://github.com/Daniel-Diaz/pcre-light
synopsis: Portable regex library for Perl 5 compatible regular expressions
description:
    A small, efficient and portable regex library for Perl 5 compatible regular expressions
    .
    The PCRE library is a set of functions that implement regular
    expression pattern matching using the same syntax and semantics as Perl 5.
    .
    If installation fails reporting that you are missing the prce C library, try installing
    the @libpcre3-dev@ package (linux).
    .
category: Text
author: Don Stewart
exposed: True
exposed-modules:
    Text.Regex.PCRE.Light Text.Regex.PCRE.Light.Char8
    Text.Regex.PCRE.Light.Base
abi: f7f6bc4d62b7b0655714a824041d8027
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pcre-light-0.4.0.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/pcre-light-0.4.0.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/pcre-light-0.4.0.4
hs-libraries: HSpcre-light-0.4.0.4-AoPPcWPoSh8CV8nUAbwYS0
extra-libraries:
    pcre
depends:
    base-4.9.0.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-pcre-light/html/pcre-light.haddock
haddock-html: /usr/share/doc/haskell-pcre-light/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-light-0.4.0.4-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-light.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-light
version: 0.4.0.4
id: pcre-light-0.4.0.4-9w7mqwxeDk7EzLDWo0Ch41
key: pcre-light-0.4.0.4-9w7mqwxeDk7EzLDWo0Ch41
license: BSD3
copyright: (c) 2007-2010. Don Stewart <dons@galois.com>
maintainer: Daniel Díaz <dhelta.diaz@gmail.com>
homepage: https://github.com/Daniel-Diaz/pcre-light
synopsis: Portable regex library for Perl 5 compatible regular expressions
description:
    A small, efficient and portable regex library for Perl 5 compatible regular expressions
    .
    The PCRE library is a set of functions that implement regular
    expression pattern matching using the same syntax and semantics as Perl 5.
    .
    If installation fails reporting that you are missing the prce C library, try installing
    the @libpcre3-dev@ package (linux).
    .
category: Text
author: Don Stewart
exposed: True
exposed-modules:
    Text.Regex.PCRE.Light Text.Regex.PCRE.Light.Char8
    Text.Regex.PCRE.Light.Base
abi: bca47bc941c3d23e560ba219475106be
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/pcre-light-0.4.0.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/pcre-light-0.4.0.4
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/pcre-light-0.4.0.4
hs-libraries: HSpcre-light-0.4.0.4-9w7mqwxeDk7EzLDWo0Ch41
extra-libraries:
    pcre
depends:
    base-4.9.1.0 bytestring-0.10.8.1
haddock-interfaces: /usr/share/doc/haskell-pcre-light/html/pcre-light.haddock
haddock-html: /usr/share/doc/haskell-pcre-light/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
